Tag getuser

## getuser get current user details

name
  getuser
xml namespace
  http://moyaproject.com/auth
defined
  /home/will/projects/moya/moya/applications/auth/logic/tags.xml (line 76)

Get currently logged in user (if any)

attributes
name | purpose | type | required?
--- | --- | --- | ---
dst | Destination | Reference | No
lazy | Enable lazy evaluation | boolean | No

inherited attributes
name | purpose | type | required?
--- | --- | --- | ---
if | Conditional expression | expression | No